Omni.Content.Text (Omni v1.2.1)

Copy Markdown View Source

A text content block.

The most common content type, representing plain text output from a model or text input from a user.

Summary

Types

t()

Text content with an optional integrity signature.

Functions

Creates a new text content block from a string, keyword list, or map.

Types

t()

@type t() :: %Omni.Content.Text{signature: String.t() | nil, text: String.t()}

Text content with an optional integrity signature.

Functions

new(text)

@spec new(String.t() | Enumerable.t()) :: t()

Creates a new text content block from a string, keyword list, or map.