A tool use content block representing the model's intent to invoke a tool.
Appears in assistant messages when the model decides to use a tool. The id
is a provider-assigned identifier that links this block to its corresponding
Omni.Content.ToolResult.
Summary
Functions
Creates a new tool use content block from a keyword list or map.
Types
Functions
@spec new(Enumerable.t()) :: t()
Creates a new tool use content block from a keyword list or map.